# API

The following pages describe the main objects and function of `nuance`

## Main modules

```{toctree}
:maxdepth: 1

core
ls
ps

```

## Other

```{eval-rst}

.. currentmodule:: nuance

.. autosummary::
   :toctree: generated
   :nosignatures:
   :template: class.rst

   Star

```